@@ -1211,11 +1211,11 @@ class WelfareVerifyAbstract(Base):
             # print("i_num_abc: ", i_num_abc)
             v_ins = sess.query(cls).get(i_num_abc)
             coll_verify.append(v_ins.verify)
-            if cls.__tablename__ == 'verifya':
+            if cls.__tablename__ == 'sd_verifya':
                 temp_num123 = str(v_ins.num1)
-            elif cls.__tablename__ == 'verifyb':
+            elif cls.__tablename__ == 'sd_verifyb':
                 temp_num123 = str(v_ins.num2)
-            elif cls.__tablename__ == 'verifyc':
+            elif cls.__tablename__ == 'sd_verifyc':
                 temp_num123 = str(v_ins.num3)
             else:
                 raise(">>> ERROR TABLENAME")
